@@ -20,7 +20,7 @@
  */
 #pragma once
 
-#include "openPMDIO/AbstractFilePosition.hpp"
+#include "openPMD/IO/AbstractFilePosition.hpp"
 
 
 namespace openPMD
@@ -29,6 +29,5 @@ struct ADIOS2FilePosition : public AbstractFilePosition
 {
     ADIOS2FilePosition()
     { }
-
-};  //ADIOS2FilePosition
+}; // ADIOS2FilePosition
 } // openPMD
